@@ -298,6 +298,27 @@ int php_amqp_set_resource_read_timeout(amqp_connection_resource *resource, doubl
 	return 1;
 }
 
+int php_amqp_set_resource_rpc_timeout(amqp_connection_resource *resource, double timeout TSRMLS_DC)
+{
+	assert(timeout >= 0.0);
+
+#if AMQP_VERSION_MAJOR * 100 + AMQP_VERSION_MINOR * 10 + AMQP_VERSION_PATCH >= 90
+	struct timeval rpc_timeout;
+
+	if (timeout == 0.) return 1;
+
+	rpc_timeout.tv_sec = (int) floor(timeout);
+	rpc_timeout.tv_usec = (int) ((timeout - floor(timeout)) * 1.e+6);
+
+	if (AMQP_STATUS_OK != amqp_set_rpc_timeout(resource->connection_state, &rpc_timeout)) {
+		zend_throw_exception(amqp_connection_exception_class_entry, "Library error: cannot set rpc_timeout", 0 TSRMLS_CC);
+		return 0;
+	}
+#endif
+
+	return 1;
+}
+
 int php_amqp_set_resource_write_timeout(amqp_connection_resource *resource, double timeout TSRMLS_DC)
 {
 	assert(timeout >= 0.0);
@@ -393,7 +414,7 @@ amqp_connection_resource *connection_resource_constructor(amqp_connection_params
 	amqp_table_entry_t client_properties_entries[5];
 	amqp_table_t       client_properties_table;
 
-	amqp_table_entry_t custom_properties_entries[1];
+	amqp_table_entry_t custom_properties_entries[2];
 	amqp_table_t       custom_properties_table;
 
 	amqp_connection_resource *resource;
@@ -471,6 +492,11 @@ amqp_connection_resource *connection_resource_constructor(amqp_connection_params
 		return NULL;
 	}
 
+	if (!php_amqp_set_resource_rpc_timeout(resource, params->rpc_timeout TSRMLS_CC)) {
+		connection_resource_destructor(resource, persistent TSRMLS_CC);
+		return NULL;
+	}
+
 	std_datetime = php_std_date(time(NULL) TSRMLS_CC);
 
 	client_properties_entries[0].key               = amqp_cstring_bytes("type");
@@ -500,8 +526,15 @@ amqp_connection_resource *connection_resource_constructor(amqp_connection_params
 	custom_properties_entries[0].value.kind        = AMQP_FIELD_KIND_TABLE;
 	custom_properties_entries[0].value.value.table = client_properties_table;
 
+
+	if (params->connection_name) {
+		custom_properties_entries[1].key               = amqp_cstring_bytes("connection_name");
+		custom_properties_entries[1].value.kind        = AMQP_FIELD_KIND_UTF8;
+		custom_properties_entries[1].value.value.bytes = amqp_cstring_bytes(params->connection_name);
+	}
+
 	custom_properties_table.entries     = custom_properties_entries;
-	custom_properties_table.num_entries = sizeof(custom_properties_entries) / sizeof(amqp_table_entry_t);
+	custom_properties_table.num_entries = params->connection_name ? 2 : 1;
 
 	/* We can assume that connection established here but it is not true, real handshake goes during login */
 
